set more off
numlabel, add force

use $data/ESS8e01, clear

*******************************************************
***********clean and prepare date *********************
*******************************************************

sort inwyys inwmms inwdds

ta inwdds, m
drop if inwdds==99

ta inwmms, m
drop if inwmms==99

ta inwyys, m
drop if inwyys==9999.

encode cntry, gen(country)
ta country, gen(country)


gen str2 day = string(inwdds,"%02.0f")
gen str2 month = string(inwmms,"%02.0f")

sort inwyys month day
egen date6 = concat(inwyys month day ), punct(".")

encode date6, gen(p3)
numlabel, add



*******************************************************
***********DV: EU unification gone too far*************
*******************************************************
ta euftf, m
recode euftf( 77 88 99 =.)

**********prepare time variable around trump election
gen trump=0 if p3<85
replace trump=1 if p3>85

****drop day immediately after election
drop if p3==85


******************************************************
***********Prepare and clean covariates***************
******************************************************

************gender
gen gender= gndr
recode gender (2=1) (1=0) (9=.)
ta gender, m

**********age
gen age=agea
recode age (999=.)
ta age, m

***********years of full-time education completed
gen edu=eduyrs
recode edu( 77 88 99 =.)
replace edu=26 if edu>26 	
ta edu, m	


*********occupation 
quietly: ta isco08, m 

recode isco08 (0 100 110 210 300 310=10 "armed forces") (1000/1439=1 "managers") (2000/2659=2 "Professionals") ///
(3000/3522=3 "Technicians and Associate Professionals") (4000/4999=4 "Clerical Support Workers" ) ///
(5000/5999=5 "Services and Sales Workers") (6000/6999=6 "Skilled Agricultural, Forestry and Fishery Workers" ) ///
(7000/7999=7 "Craft and Related Trades Workers") (8000/8999=8 "Plant and Machine Operators and Assemblers") ///
(9000/9629 =9 "Elementary Occupations"), into (isko)

**********town vs village
ta domicil, m

gen urban=domicil
recode urban (1 2 3 =1) ( 4 5=0) ( 7 8 9=.)

ta urban domicil, m
 
 ********student retired etc.
ta mnactic, m
recode mnactic (77 88 99=.) (1=1 "paid work") (2=2 "student (education)") (3 4 5=3 "unemployed") (6=4 "retired") ///
(8=5 "homemaker") (7 9 =6 "other"), into (occ) 
ta occ, gen(occ)

quietly: ta occ mnactic, m


**************clean and recode countries

#delimit ;
lab def lab			1 "Austria" 
					2 "Belgium"
					3 "Switzerland" 	
					4 "Czechia"
					5 "Germany"
					6 "Estonia"
					7 "Finland"
					8 "France"
					9 "GB"
					10 "Iceland"
					11 "Ireland"
					12 "Israel"
					13 "Netherlands"
					14 "Norway"
					15 "Poland"
					16 "Russia"
					17 "Sweden"
					18 "Slovenia";
#delimit cr



lab values country lab
numlabel, add
ta country


*****restrict time frame around presidential eleciton of trump
keep if p3>76 & p3<96

**************drop day directly after presidential election 
drop if p3==85

gen p3_c=p3-86

*************generate help variable for holding sample sizes constant in stepwise Regression
reg euftf trump age urban i.occ edu gender if p3>76 & p3<96, vce(robust)
gen gueltig2=e(sample)



*************************************************************************************************************
**************************descriptives***********************************************************************
*************************************************************************************************************

***********covariates
eststo: estpost summarize euftf edu gender occ1 occ2 occ3 occ4 occ5 occ6 age urban if trump==0 & gueltig2==1

eststo: estpost summarize euftf edu gender occ1 occ2 occ3 occ4 occ5 occ6 age urban if trump==1 & gueltig2==1

esttab using $tab/TableS17.rtf, replace cell("count mean(fmt(a2)) sd(fmt(a2)) min(fmt(a2)) max(fmt(a2))") ///
mti collabels(none) nonum noobs label nodepvar mlabels(,none)   ///
title ("Table S17. Descriptive statistics, European Social Survey.") ///
addnotes ("ESS Round 8, own calculations, not weighted; SD=Standard deviation, education was top-coded at 26 years to reduce the influence of outliers.")

eststo clear

**************check for covariate imbalances in sample (Table S17)
foreach u in euftf edu gender occ1 occ2 occ3 occ4 occ5 occ6 age gender urban age urban{
di "`u'"
ttest `u' if gueltig2==1, by(trump) level(95) unequal
ttest `u' if gueltig2==1, by(trump) level(99) unequal
ttest `u' if gueltig2==1, by(trump) level(99.9) unequal
}


********************************************************************************
**************Regressions using ESS as robustness check*************************
********************************************************************************

reg euftf trump  if gueltig2==1, vce(robust)
eststo
reg euftf trump i.occ edu age urban gender if gueltig2==1, vce(robust)
eststo


#delimit ;
esttab	using $tab/TableS16.rtf, replace 
	nonumbers
	b(%9.2f) se(2) wide
	r2(2) 
	label
	compress
	mlabels ("(1)" "(2)")
	nogaps
	title ("Table S16. Robustness-check: Main model replicated with ESS data. DV: “EU integration should go further” (Scale: 1-10).")
	star
	addnotes ("Treatment group: Interviewed after November 9. Robust standard errors in parentheses. Own calculations, based on ESS Round 8, not weighted.")
;
#delimit cr

eststo clear



*******check cases before and after election of trump
ta trump

*******graph distribution of observations in ESS (Figure S3)
graph twoway kdensity p3 if country==1, bwidth(2) lcolor(gs10) lpattern(--) || ///
			 kdensity p3 if country==2, bwidth(2) lcolor(gs10) lpattern(--) || ///
			 kdensity p3  if country==3, bwidth(2) lcolor(gs10) lpattern(--) || ///
			 kdensity p3  if country==4, bwidth(2) lcolor(gs10) lpattern(--) || ///
			 kdensity p3  if country==5, bwidth(2) lcolor(gs10) lpattern(--) || ///
			 kdensity p3  if country==6, bwidth(2) lcolor(gs10) lpattern(--) || ///
			 kdensity p3  if country==7, bwidth(2) lcolor(gs10) lpattern(--) || ///
			 kdensity p3  if country==8, bwidth(2) lcolor(gs10) lpattern(--) || ///
			 kdensity p3  if country==9, bwidth(2) lcolor(gs10) lpattern(--) || ///
			 kdensity p3  if country==10, bwidth(2) lcolor(gs10) lpattern(--) || ///
			 kdensity p3  if country==11, bwidth(2) lcolor(gs10) lpattern(--) || ///
			 kdensity p3  if country==12, bwidth(2) lcolor(gs10) lpattern(--) || ///
			 kdensity p3  if country==13, bwidth(2) lcolor(gs10) lpattern(--) || ///
			 kdensity p3  if country==14, bwidth(2) lcolor(gs10) lpattern(--) || ///
			 kdensity p3  if country==15, bwidth(2) lcolor(gs10) lpattern(--) || ///
			 kdensity p3  if country==16, bwidth(2) lcolor(gs10) lpattern(--) || ///
			 kdensity p3  if country==17, bwidth(2) lcolor(gs10) lpattern(--) || ///
			 kdensity p3  if country==18, bwidth(2) lcolor(gs10) lpattern(--) || ///
			 kdensity p3, bwidth(2) lcolor(black) lpattern(solid) xline(84.5, lcolor(cranberry) lwidth(0.5)) ///
			 legend(off) xtitle("") ytitle("Relative frequency of observations") ///
			 xscale(range(77(3)96)) xlabel( 77 "1st" 80 "4th" 83 "7th" 86 "10th" 89 "13th" 92 "16th" ///
			 95 "19th") ///
			 text(.13 80 "N(pre-Trump)=2,439", color(cranberry)) text(.13 90 "N(post-Trump)=2,997", color(cranberry))

gr export $graph/FigureS3.pdf, as(pdf) replace
