set more off

use $data\EB78.1_Nov2012_ZA5685_v2-0-0.dta, clear

**************generate placebo treatment variable (presidential election of Obama - we still call it 'trump')
gen trump=.
replace trump=1 if p1>6
replace trump=0 if p1<7
ta p1 trump

lab variable trump "Treatment group"


**************clean and recode countries (drop Bulgaria)
numlabel, add
ta country, m
drop if country==29

gen count=.

replace count=1  if country==1
replace count=2  if country==2
replace count=3  if country==3
replace count=4  if country==4 | country==14
replace count=5  if country==5
replace count=6  if country==6
replace count=7  if country==7
replace count=8  if country==8
replace count=9  if country==9 | country==10
replace count=10 if country==11
replace count=11 if country==12
replace count=12 if country==13
replace count=13 if country==16
replace count=14 if country==17
replace count=15 if country==18
replace count=16 if country==19 | country==33
replace count=17 if country==20
replace count=18 if country==21
replace count=19 if country==22
replace count=20 if country==23
replace count=21 if country==24
replace count=22 if country==25
replace count=23 if country==26
replace count=24 if country==27
replace count=25 if country==28
replace count=26 if country==30
replace count=27 if country==31
replace count=28 if country==32
replace count=29 if country==34
replace count=30 if country==35
replace count=31 if country==36
replace count=32 if country==43 

 #delimit ;

lab def labcountry  1 "France" 
					2 "Belgium"
					3 "Netherlands" 	
					4 "Germany"
					5 "Italy"
					6 "Luxembourg"
					7 "Denmark"
					8 "Ireland"
					9 "UK"
					10 "Greece"
					11 "Spain"
					12 "Portugal"
					13 "Finland"
					14 "Sweden"
					15 "Austria"
					16 "Cyprus"
					17 "Czech Republic"
					18 "Estonia"
					19 "Hungary"
					20 "Latvia"
					21 "Lithuania"
					22 "Malta"
					23 "Poland"
					24 "Slovakia"
					25 "Slovenia"
					26 "Romania"
					27 "Turkey"
					28 "Croatia"
					29 "Macedonia/FYROM"
					30 "Montenegro"
					31 "Serbia"
					32 "Iceland";		
  #delimit cr


lab val count labcountry

drop country 
rename count country



******************************************************
***********Prepare and clean covariates***************
******************************************************

****************gender 
ta d10, m
gen frau=d10
recode frau (1=0) (2=1)

lab var frau "Female"

ta frau d10


*******************education in years
ta d8, m
gen bilzeit=d8 
replace bilzeit=26 if bilzeit>26 & bilzeit<96
ta bilzeit
recode bilzeit(.d .r=.)

replace bilzeit=0 if d8==97 | d8==98

lab var bilzeit "Education (in years)"

compare d8 bilzeit 


**********************occupation
ta d15a_r2
gen occ_kat=d15a_r2

recode occ_kat (1=1) (2 3=2) (4=3) (5=4) (6=5) (7=6) (8=7)

ta occ_kat d15a_r2
lab def labelocc	1 "Self-employed" ///
					2 "White collar"  ///
					3 "Manual" ///
					4 "Homemaker" ///
					5 "Unemployed" ///
					6 "Retired" ///
					7 "Student"
					
lab val occ_kat labelocc 

ta occ_kat, gen(occ)
lab var occ1 "Self-employed" 
lab var occ2 "White collar"  
lab var occ3 "Manual" 
lab var occ4 "Homemaker" 
lab var occ5 "Unemployed"
lab var occ6 "Retired" 
lab var occ7 "Student"

ta occ_kat d15a_r2, m


*****************age
ta d11, m

gen age=d11
recode age (99=.)

lab var age "Age"
compare age d11


*****************rural vs. urban
gen town=d25
recode town (1=0) (2 3=1)

lab var town "small/middle/large Town"

ta town d25, m


**************************************************************
**************** Trust DV*************************************
**************************************************************
**********************trust in european union
ta  qa11_8,m 

gen trust=.
replace trust=1 if  qa11_8==1 
replace trust=0 if  qa11_8==2 

lab def trustlab 1 "Tend to trust" ///
				 0 "Tend not to trust"

label values trust trustlab
				 
lab variable trust "Trust in EU"

ta trust qa11_8,m 


**************************************************************
****************clean and save data set***********************
**************************************************************
keep country trump p1 frau bilzeit  occ* age* town* trust eu28 eu27

save $data\eurobarometer2012obama, replace


*********************************************************************
**************** Analysis *******************************************
*********************************************************************
numlabel, add force

**********************drop countries that are not EU28
drop if eu28==0
ta country, m

#delimit ;

lab def labcount 	1 "France" 
					2 "Belgium"
					3 "Netherlands" 	
					4 "Germany"
					5 "Italy"
					6 "Luxembourg"
					7 "Denmark"
					8 "Ireland"
					9 "UK"
					10 "Greece"
					11 "Spain"
					12 "Portugal"
					13 "Finland"
					14 "Sweden"
					15 "Austria"
					16 "Cyprus"
					17 "Czech Republic"
					18 "Estonia"
					19 "Hungary"
					20 "Latvia"
					21 "Lithuania"
					22 "Malta"
					23 "Poland"
					24 "Slovakia"
					25 "Slovenia"
					26 "Romania"
					27 "Croatia";
#delimit cr


lab values country labcount
ta country

ta country, gen(country)

**************drop day directly after Obamas election
drop if  p1==7  
ta p1

***************************date of interview
gen zeit=.
replace zeit=1  if p1==3
replace zeit=2  if p1==4
replace zeit=3  if p1==5
replace zeit=4  if p1==6
replace zeit=5  if p1==8
replace zeit=6  if p1==9
replace zeit=7  if p1==10
replace zeit=8  if p1==11
replace zeit=9  if p1==12
replace zeit=10  if p1==13
replace zeit=11  if p1==14
replace zeit=12  if p1==15
replace zeit=13  if p1==16
replace zeit=14  if p1==17
replace zeit=15  if p1==18

ta zeit p1, m
ta zeit trump, m

*****************generate centered time variable
gen trump_c=zeit
replace trump_c=trump_c-5
 
ta zeit trump_c , m
ta trump trump_c
ta p1 trump_c


*************generate help variable for holding sample sizes constant in stepwise Regression
logit trust trump i.frau age i.town bilzeit occ1 occ3 occ4 occ5 occ6 occ7 b27.country, vce (robust) 
gen gueltig=e(sample)


*************************************************************************************************************
**************************Regressions using trust in EU as robustness check**********************************
*************************************************************************************************************
logit trust trump i.frau age i.town bilzeit occ1 occ3 occ4 occ5 occ6 occ7 ///
if gueltig==1, vce (robust) 
est sto trust

logit trust trump i.frau age i.town bilzeit occ1 occ3 occ4 occ5 occ6 occ7 ///
i.country if gueltig==1, vce (robust) 
est sto trustcount


#delimit ;
esttab trust trustcount using $tab\TableS13.rtf, replace nonumbers
	b(%-9.0g 3) se(3)  wide
	star(* 0.05 ** 0.01 *** 0.001)
	label
	compress
	drop(*country)
	nogaps
	aic bic
	scalars(ll chi2 chi2_c)
	title ("Table S13. Logit regression, external shock: Obama’s 2012 reelection, DV: Trust in the EU.")
	addnotes ("Robust errors in parentheses, own calculations, based on Eurobarometer 78.2 (2012), not weighted. ")
;
#delimit cr
