set more off

use $data\eurobarometer2016Trump2, clear

**********************drop countries that do not belong to the EU
ta country
drop if country==27 | country>28
recode country (28=27 )

#delimit ;

lab def labcount 	1 "France" 
					2 "Belgium"
					3 "Netherlands" 	
					4 "Germany"
					5 "Italy"
					6 "Luxembourg"
					7 "Denmark"
					8 "Ireland"
					9 "UK"
					10 "Greece"
					11 "Spain"
					12 "Portugal"
					13 "Finland"
					14 "Sweden"
					15 "Austria"
					16 "Cyprus"
					17 "Czech Republic"
					18 "Estonia"
					19 "Hungary"
					20 "Latvia"
					21 "Lithuania"
					22 "Malta"
					23 "Poland"
					24 "Slovakia"
					25 "Slovenia"
					26 "Romania"
					27 "Croatia";
#delimit cr


lab values country labcount

ta country, gen(country)

**************drop day directly after election
drop if  p1==7  
ta p1

***************************interview date
gen zeit=.
replace zeit=1  if p1==3
replace zeit=2  if p1==4
replace zeit=3  if p1==5
replace zeit=4  if p1==6
replace zeit=5  if p1==8
replace zeit=6  if p1==9
replace zeit=7  if p1==10
replace zeit=8  if p1==11
replace zeit=9  if p1==12



*****************generate centered time variable
gen trump_c=zeit
replace trump_c=trump_c-5
 
***********************************************************************************************************
******************************************Factor analysis**************************************************
***********************************************************************************************************
global fact2 mod demos protec effic forw optifut jobs busni demo attacheu  ///
eucitizen respect 
 
su $fact2

alpha $fact2, item 
alpha $fact2

corr $fact2

factor $fact2

screeplot, yline(1)

factor  $fact2, factor(1) blanks(0.3)

predict f1bart, bartlett
label var f1bart "EU popularity index"


*************************************************************************************************************
********************************Regresssions and descriptives************************************************
*************************************************************************************************************

*************generate help variable for holding sample sizes constatn in stepwise Regression
quietly: reg f1bart trump i.frau age i.town bilzeit occ_kat1 occ_kat3 occ_kat4 occ_kat5 occ_kat6 occ_kat7 b27.country, vce (robust) 
gen gueltig=e(sample)


**********************overall regression
foreach u in unemp_grob281 unemp_grob282 unemp_grob283 partisan_kat1 partisan_kat2 partisan_kat3 ///
count_econ1 count_econ2 count_econ3 count_econ4 eunationalcit1 eunationalcit2 eunationalcit3 eunationalcit4 ///
unempchange_kat1 unempchange_kat2 unempchange_kat3{
quietly: reg f1bart trump i.frau age i.town bilzeit occ_kat1 occ_kat3 occ_kat4 occ_kat5 occ_kat6 occ_kat7 i.country if `u'==1, vce (robust) 
gen gueltig_`u'=e(sample)
}

****************centering
center frau bilzeit age occ_kat1 occ_kat2 occ_kat3 occ_kat4 occ_kat5 occ_kat6 occ_kat7 town if gueltig==1, prefix(c_) 
su c_*
forval i=1/27{
quietly: center country`i' if gueltig==1, prefix(c_)
}

foreach u in unemp_grob281 unemp_grob282 unemp_grob283 partisan_kat1 partisan_kat2 partisan_kat3 ///
count_econ1 count_econ2 count_econ3 count_econ4 eunationalcit1 eunationalcit2 eunationalcit3 eunationalcit4 ///
unempchange_kat1 unempchange_kat2 unempchange_kat3{
quietly: center frau age town bilzeit occ_kat1 occ_kat2 occ_kat3 occ_kat4 occ_kat5 occ_kat6 occ_kat7 if gueltig_`u'==1, prefix(c`u'_) 
}

forval i=1/27{
foreach u in unemp_grob281 unemp_grob282 unemp_grob283 partisan_kat1 partisan_kat2 partisan_kat3 ///
count_econ1 count_econ2 count_econ3 count_econ4 eunationalcit1 eunationalcit2 eunationalcit3 eunationalcit4 ///
unempchange_kat1 unempchange_kat2 unempchange_kat3 {
quietly: center country`i' if gueltig_`u'==1, prefix(c`u'_) 
}
}



****************************************set globals for regression models

**************unemployment
global unemp1 i.trump cunemp_grob281_frau cunemp_grob281_age cunemp_grob281_occ_kat1 ///
cunemp_grob281_occ_kat3 cunemp_grob281_occ_kat4 cunemp_grob281_occ_kat5 cunemp_grob281_occ_kat6 ///
cunemp_grob281_occ_kat7 cunemp_grob281_town cunemp_grob281_bilzeit cunemp_grob281_country3 ///
cunemp_grob281_country4 cunemp_grob281_country6 cunemp_grob281_country7 cunemp_grob281_country15 ///
cunemp_grob281_country17 cunemp_grob281_country19  cunemp_grob281_country22
 
global unemp2 i.trump cunemp_grob282_frau cunemp_grob282_age cunemp_grob282_occ_kat1 ///
cunemp_grob282_occ_kat3 cunemp_grob282_occ_kat4 cunemp_grob282_occ_kat5 cunemp_grob282_occ_kat6 ///
cunemp_grob282_occ_kat7 cunemp_grob282_town cunemp_grob282_bilzeit cunemp_grob282_country2 ///
cunemp_grob282_country8 cunemp_grob282_country13 cunemp_grob282_country14 cunemp_grob282_country18 ///
cunemp_grob282_country21 cunemp_grob282_country25 cunemp_grob282_country26


global unemp3 i.trump cunemp_grob283_frau cunemp_grob283_age cunemp_grob283_occ_kat1 ///
cunemp_grob283_occ_kat3 cunemp_grob283_occ_kat4 cunemp_grob283_occ_kat5 cunemp_grob283_occ_kat6 ///
cunemp_grob283_occ_kat7 cunemp_grob283_town cunemp_grob283_bilzeit cunemp_grob283_country1 ///
cunemp_grob283_country5 cunemp_grob283_country10 cunemp_grob283_country11 cunemp_grob283_country16 ///
cunemp_grob283_country20 cunemp_grob283_country24 cunemp_grob283_country27


*******eu or national citizen
global eunat1 i.trump ceunationalcit1_frau ceunationalcit1_age ceunationalcit1_occ_kat1 ///
ceunationalcit1_occ_kat3 ceunationalcit1_occ_kat4 ceunationalcit1_occ_kat5 ceunationalcit1_occ_kat6 ///
ceunationalcit1_occ_kat7 ceunationalcit1_town ceunationalcit1_bilzeit ceunationalcit1_country*

global eunat2 i.trump ceunationalcit2_frau ceunationalcit2_age ceunationalcit2_occ_kat1 ///
ceunationalcit2_occ_kat3 ceunationalcit2_occ_kat4 ceunationalcit2_occ_kat5 ceunationalcit2_occ_kat6 ///
ceunationalcit2_occ_kat7 ceunationalcit2_town ceunationalcit2_bilzeit ceunationalcit2_country*

global eunat3 i.trump ceunationalcit3_frau ceunationalcit3_age ceunationalcit3_occ_kat1 ///
ceunationalcit3_occ_kat3 ceunationalcit3_occ_kat4 ceunationalcit3_occ_kat5 ceunationalcit3_occ_kat6 ///
ceunationalcit3_occ_kat7 ceunationalcit3_town ceunationalcit3_bilzeit ceunationalcit3_country*

global eunat4 i.trump ceunationalcit4_frau ceunationalcit4_age ceunationalcit4_occ_kat1 ///
ceunationalcit4_occ_kat3 ceunationalcit4_occ_kat4 ceunationalcit4_occ_kat5 ceunationalcit4_occ_kat6 ///
ceunationalcit4_occ_kat7 ceunationalcit4_town ceunationalcit4_bilzeit ceunationalcit4_country*


*******partisanship
global part1 i.trump cpartisan_kat1_frau cpartisan_kat1_age cpartisan_kat1_occ_kat1 ///
cpartisan_kat1_occ_kat3 cpartisan_kat1_occ_kat4 cpartisan_kat1_occ_kat5 cpartisan_kat1_occ_kat6 ///
cpartisan_kat1_occ_kat7 cpartisan_kat1_town cpartisan_kat1_bilzeit cpartisan_kat1_country*

global part2 i.trump cpartisan_kat2_frau cpartisan_kat2_age cpartisan_kat2_occ_kat1 ///
cpartisan_kat2_occ_kat3 cpartisan_kat2_occ_kat4 cpartisan_kat2_occ_kat5 cpartisan_kat2_occ_kat6 ///
cpartisan_kat2_occ_kat7 cpartisan_kat2_town cpartisan_kat2_bilzeit cpartisan_kat2_country*

global part3 i.trump cpartisan_kat3_frau cpartisan_kat3_age cpartisan_kat3_occ_kat1 ///
cpartisan_kat3_occ_kat3 cpartisan_kat3_occ_kat4 cpartisan_kat3_occ_kat5 cpartisan_kat3_occ_kat6 ///
cpartisan_kat3_occ_kat7 cpartisan_kat3_town cpartisan_kat3_bilzeit cpartisan_kat3_country*


****economic situation
global econ1 i.trump ccount_econ1_frau ccount_econ1_age ccount_econ1_occ_kat1 ///
ccount_econ1_occ_kat3 ccount_econ1_occ_kat4 ccount_econ1_occ_kat5 ccount_econ1_occ_kat6 ///
ccount_econ1_occ_kat7 ccount_econ1_town ccount_econ1_bilzeit ccount_econ1_country*

global econ2 i.trump ccount_econ2_frau ccount_econ2_age ccount_econ2_occ_kat1 ///
ccount_econ2_occ_kat3 ccount_econ2_occ_kat4 ccount_econ2_occ_kat5 ccount_econ2_occ_kat6 ///
ccount_econ2_occ_kat7 ccount_econ2_town ccount_econ2_bilzeit ccount_econ2_country*

global econ3 i.trump ccount_econ3_frau ccount_econ3_age ccount_econ3_occ_kat1 ///
ccount_econ3_occ_kat3 ccount_econ3_occ_kat4 ccount_econ3_occ_kat5 ccount_econ3_occ_kat6 ///
ccount_econ3_occ_kat7 ccount_econ3_town ccount_econ3_bilzeit ccount_econ3_country*

global econ4 i.trump ccount_econ4_frau ccount_econ4_age ccount_econ4_occ_kat1 ///
ccount_econ4_occ_kat3 ccount_econ4_occ_kat4 ccount_econ4_occ_kat5 ccount_econ4_occ_kat6 ///
ccount_econ4_occ_kat7 ccount_econ4_town ccount_econ4_bilzeit ccount_econ4_country*



*************************************************************************************************************
**************************descriptives***********************************************************************
*************************************************************************************************************

***********covariates
eststo: estpost summarize f1bart bilzeit frau occ_kat1 occ_kat2 occ_kat3 occ_kat4 occ_kat5 occ_kat6 occ_kat7 age ///
town if trump==0 & gueltig==1

eststo: estpost summarize f1bart bilzeit frau occ_kat1 occ_kat2 occ_kat3 occ_kat4 occ_kat5 occ_kat6 occ_kat7 age ///
town if trump==1 & gueltig==1

esttab using 	$tab/Table1.rtf, replace ///
				cell("count mean(fmt(a2)) sd(fmt(a2)) min(fmt(a2)) max(fmt(a2))") ///
				mti collabels(none) nonum noobs label nodepvar ///
				mlabels(,none) title ("Table 1. Descriptive statistics.") ///
				addnotes ("Note: Based on Eurobarometer 86.2, own calculations, not weighted; SD=Standard deviation, education was top-coded at 26 years to reduce the influence of outliers. ")
eststo clear

*********countries
eststo: estpost summarize country* if trump==0 & gueltig==1

eststo: estpost summarize country* if trump==1 & gueltig==1

esttab using 	$tab/TableS4.rtf, replace ///
				cell("count mean(fmt(a2)) sd(fmt(a2)) min(fmt(a2)) max(fmt(a2))") ///
				mti collabels(none) nonum noobs label nodepvar ///
				mlabels(,none) title ("Table S4: Descriptive statistics") ///
				addnotes ("EB 2016, own calculations, not weighted")
				
eststo clear


**************check for imbalances in covariates for sample (Table 1)
foreach u in f1bart bilzeit frau occ_kat1 occ_kat2 occ_kat3 occ_kat4 occ_kat5 occ_kat6 occ_kat7 ///
age town{
di "`u'"
ttest `u' if gueltig==1, by(trump) level(99.9) unequal
}


**************check for imbalances in covariates for sample (Table S4)
forval u=1/27{
di "`u'"
di "`country*'"
ttest country`u' if gueltig==1, by(trump) level(99.9) unequal
}


*************************************************************************************************************
**************************Regressions dividing countries by fieldwork phase**********************************
*************************************************************************************************************

******excluding countries that were overrepreseneted in control group (before election)
reg f1bart trump i.frau age i.town bilzeit occ_kat1 occ_kat3 occ_kat4 occ_kat5 occ_kat6 occ_kat7  ///
if country==1 | country==2 | country==3 | country==4 | country==5 | country==6 | country==7 | country==10 ///
| country==15 | country==16 | country==21 | country==18 , vce (robust)
est sto before

******excluding countries that were overrepreseneted in treatment group (after election)
reg f1bart trump i.frau age i.town bilzeit occ_kat1 occ_kat3 occ_kat4 occ_kat5 occ_kat6 occ_kat7 ///
if country==8 | country==9 | country==11 | country==12  | country==19 ///
| country==24 | country==26 | country==27, vce (robust) 
est sto after
  
 
 #delimit ;
esttab  before after  using $tab/TableS5.rtf, replace 
	nonumbers
	b(%9.3f) se(3) wide
	r2(2) 
	label
	compress
	nogaps
	mlabels ("Oversampled after pred. election" "Oversampled before pred. election" )
	title ("Table S5. Robustness check for imbalances in fieldwork. DV: EU popularity index.")
	star
	addnotes ("Treatment group: Interviewed after the presidential election. Robust standard errors in parentheses. EB 2016, own calculations, not weighted.")
;
#delimit cr



*************************************************************************************************************
**************************probit Models**********************************************************************
*************************************************************************************************************

*********eu or national citizen
probit trump bilzeit i.frau age i.town ib2.occ_kat ib2.eunationalcit if gueltig==1
est store eunat


******partisanship
probit trump bilzeit i.frau age i.town ib2.occ_kat i.partisan_kat if gueltig==1
est store partisan


 #delimit ;
esttab partisan eunat using $tab\TableS10.rtf, replace nonumbers
	b(%-9.0g 3) se(3)  wide
	star(* 0.05 ** 0.01 *** 0.001)
	label
	compress
	nogaps
	aic bic
	scalars(ll chi2 chi2_c)
	title ("Table S10. Probit regression predicting the probability of being in the treatment group")
	addnotes ("Note: Standard errors in parentheses. Own calculations, based on Eurobarometer 86.2, not weighted.")
;
#delimit cr

*************************************************************************************************************
**************************Main model*************************************************************************
*************************************************************************************************************

*******************without centering
reg f1bart trump if gueltig==1, vce (robust)
est sto small
reg f1bart trump frau age occ_kat1 occ_kat3 occ_kat4 occ_kat5 occ_kat6 occ_kat7 town bilzeit b27.country if gueltig==1, vce (robust) 
est sto norm 
reg f1bart i.trump##c.trump_c frau age  occ_kat1 occ_kat3 occ_kat4 occ_kat5 occ_kat6 occ_kat7 town bilzeit b27.country if gueltig==1, vce (robust) 
est sto interact


#delimit ;
esttab small norm interact using $tab/Table3.rtf, replace 
	nonumbers
	b(%9.3f) se(3) wide
	r2(2) 
	label
	compress
	nogaps
	drop(*country)
	title ("Table 3. OLS regression. DV: EU popularity index.")
	star
	addnotes ("Note: Treatment group: Interviewed after November 9. Robust standard errors in parentheses. Own calculations based on Eurobarometer 86.2, not weighted.")
;
#delimit cr


********************Regressionen with centered covariates
reg f1bart i.trump c_frau c_age  c_occ_kat1 c_occ_kat3 c_occ_kat4 c_occ_kat5 c_occ_kat6 c_occ_kat7  ///
c_town c_bilzeit c_country* if gueltig==1, vce (robust)

scalar pval =el(r(table),4,2)
scalar trumpx =el(r(table),1,2)
scalar consx =el(r(table),1,40)
local d  `:di %9.3f _b[1.trump]'
local se `:di %9.2f _se[1.trump]'

graph  twoway 	function y=consx, range(-4 -1) lwidth(thick) lcolor(gs9) || ///
				function y=(trumpx+consx), range(0 4) lwidth(thick) lcolor(gs0) ///
				,text(.03 -3 "{&delta}{sup:RD} =`d' (`se')**", place (e)) ///
				,ylabel(-.04 -.02 0  .02  .04 ) ysc(r(-0.04(0.01)0.04)) ///
				ytitle("EU popularity index") xtitle("Days to election") ///
				legend(off) saving($graph\Figure3, replace) 
	
gr export $graph\Figure3.pdf, as(pdf) replace
erase $graph\Figure3.gph

*************************************************************************************************************   
***************subgroup analysis*****************************************************************************
*************************************************************************************************************

************************by partisanship
reg f1bart trump frau age occ_kat1 occ_kat3 occ_kat4 occ_kat5 occ_kat6 occ_kat7 town bilzeit b27.country if gueltig==1 & partisan_kat==1, vce (robust)
eststo
reg f1bart trump frau age occ_kat1 occ_kat3 occ_kat4 occ_kat5 occ_kat6 occ_kat7 town bilzeit b27.country if gueltig==1 & partisan_kat==2, vce (robust)
eststo
reg f1bart trump frau age occ_kat1 occ_kat3 occ_kat4 occ_kat5 occ_kat6 occ_kat7 town bilzeit b27.country if gueltig==1 & partisan_kat==3, vce (robust)
eststo


#delimit ;
esttab	using $tab/TableA2.rtf, replace 
	nonumbers
	b(%9.3f) se(2) wide
	r2(2) 
	label
	compress
	mlabels ("Left" "Center" "Right")
	nogaps
	drop(*country)
	title ("Table A2. Subgroup analysis by partisanship. DV: EU popularity index.")
	star
	addnotes ("Treatment group: Interviewed after November 9. Robust standard errors in parentheses. Own calculations, based on Eurobarometer 86.2, not weighted.")
;
#delimit cr

eststo clear



**************************************by unemployment
reg f1bart trump frau age occ_kat1 occ_kat3 occ_kat4 occ_kat5 occ_kat6 occ_kat7 town bilzeit b9.country if gueltig==1 & unemp_grob28==1, vce (robust)
eststo
reg f1bart trump frau age  occ_kat1 occ_kat3 occ_kat4 occ_kat5 occ_kat6 occ_kat7 town bilzeit b23.country if gueltig==1 & unemp_grob28==2, vce (robust)
eststo
reg f1bart trump frau age  occ_kat1 occ_kat3 occ_kat4 occ_kat5 occ_kat6 occ_kat7 town bilzeit b12.country if gueltig==1 & unemp_grob28==3, vce (robust)
eststo


#delimit ;
esttab	using $tab/TableS6.rtf, replace  
	nonumbers
	b(%9.3f) se(2) wide
	r2(2) 
	label
	compress
	mlabels ("Low unemployment" "Medium unemployment" "High unemployment")
	nogaps
	drop(*country)
	title ("Table S6. Subgroup analysis by unemployment rate. DV: EU popularity index.")
	star
	addnotes ("Treatment group: Interviewed after November 9. Robust standard errors in parentheses. Own calculations, based on Eurobarometer 86.2, not weighted.")
;
#delimit cr
eststo clear


************************************by unemployment change rate
reg f1bart trump frau age occ_kat1 occ_kat3 occ_kat4 occ_kat5 occ_kat6 occ_kat7 town bilzeit b9.country if gueltig==1 & unempchange_kat==1, vce (robust)
eststo
reg f1bart trump frau age  occ_kat1 occ_kat3 occ_kat4 occ_kat5 occ_kat6 occ_kat7 town bilzeit b18.country if gueltig==1 & unempchange_kat==2, vce (robust)
eststo
reg f1bart trump frau age  occ_kat1 occ_kat3 occ_kat4 occ_kat5 occ_kat6 occ_kat7 town bilzeit b27.country if gueltig==1 & unempchange_kat==3, vce (robust)
eststo


#delimit ;

esttab	using $tab/TableS7.rtf, replace 
	nonumbers
	b(%9.3f)  se(2) wide
	r2(2) 
	label
	compress
	mlabels ("Low increase in unemployment" "Medium increase in unemployment" "High increase in unemployment")
	nogaps
	drop(*country)
	title ("Table S7. Subgroup analysis by unemployment change rate (i.e., 2016 unemployment rate - 2007 unemployment rate, split in terciles).")
	star
	addnotes ("Treatment group: Interviewed after the presidential election. Low unemployment increase= low unemployment increase or decrease; Medium unemployment increase= between second and third EU-28 unemployment increase tercile; High unemployment = bigger than third eu28 unemployment change tercile. Robust standard errors in parentheses. Own calculations, based on Eurobarometer 86.2, not weighted. ")
;
#delimit cr
eststo clear


******************************************by eu or national citizen
reg f1bart trump frau age occ_kat1 occ_kat3 occ_kat4 occ_kat5 occ_kat6 occ_kat7 town bilzeit b27.country if gueltig==1 & eunationalcit==1, vce (robust)
eststo
reg f1bart trump frau age occ_kat1 occ_kat3 occ_kat4 occ_kat5 occ_kat6 occ_kat7 town bilzeit b27.country if gueltig==1 & eunationalcit==2, vce (robust)
eststo
reg f1bart trump frau age occ_kat1 occ_kat3 occ_kat4 occ_kat5 occ_kat6 occ_kat7 town bilzeit b27.country if gueltig==1 & eunationalcit==3, vce (robust)
eststo
reg f1bart trump frau age occ_kat1 occ_kat3 occ_kat4 occ_kat5 occ_kat6 occ_kat7 town bilzeit b27.country if gueltig==1 & eunationalcit==4, vce (robust)
eststo


#delimit ;
esttab	using $tab/TableS9.rtf, replace
	nonumbers
	b(%9.3f) se(2) wide
	r2(2) 
	label
	compress
	mlabels ("[Nationality] only" "[Nationality] and European" "European and [nationality]" "European only")
	nogaps
	drop(*country)
	title ("Table S9. Subgroup analysis by territorial identification. DV: EU popularity index.")
	star
	addnotes ("Treatment group: Interviewed after November 9. Robust standard errors in parentheses. Own calculations, based on Eurobarometer 86.2, not weighted.")
;
#delimit cr

eststo clear



************************by perceived economic situation of the country
reg f1bart trump frau age occ_kat1 occ_kat3 occ_kat4 occ_kat5 occ_kat6 occ_kat7 town bilzeit b27.country if gueltig==1 & count_econ==1, vce (robust)
eststo
reg f1bart trump frau age occ_kat1 occ_kat3 occ_kat4 occ_kat5 occ_kat6 occ_kat7 town bilzeit b27.country if gueltig==1 & count_econ==2, vce (robust)
eststo
reg f1bart trump frau age occ_kat1 occ_kat3 occ_kat4 occ_kat5 occ_kat6 occ_kat7 town bilzeit b27.country if gueltig==1 & count_econ==3, vce (robust)
eststo
reg f1bart trump frau age occ_kat1 occ_kat3 occ_kat4 occ_kat5 occ_kat6 occ_kat7 town bilzeit b27.country if gueltig==1 & count_econ==4, vce (robust)
eststo


#delimit ;
esttab	using $tab/TableA1.rtf, replace 
	nonumbers
	b(%9.3f) se(2) wide
	r2(2) 
	label
	compress
	mlabels ("Very bad" "Rather bad" "Rather good" "Very good")
	nogaps
	drop(*country)
	title ("Table A1. Subgroup analysis by perceived economic situation of the country. DV: EU popularity index.")
	star
	addnotes ("Treatment group: Interviewed after November 9. Robust standard errors in parentheses. Own calculations, based on Eurobarometer 86.2, not weighted.")
;
#delimit cr

eststo clear



*************************graphs for subgroup analysis

******************by partisanship
reg f1bart $part1 if partisan_kat==1 & gueltig_partisan_kat1==1, vce (robust)

scalar pval =el(r(table),4,2)
scalar trumpx =el(r(table),1,2)
scalar consx =el(r(table),1,40)
local d  `:di %9.3f _b[1.trump]'
local se `:di %9.2f _se[1.trump]'

graph  twoway 	function y=consx, range(-4 -1) lwidth(thick) lcolor(gs9) ///
				|| function y=(trumpx+consx), range(0 4) lwidth(thick) lcolor(gs0) ///
				,text(.05 -3 "{&delta}{sup:RD} =`d' (`se')", place (e)) ///
				,ylabel(-.08 -.04  0 .04  .08) ///
				ysc(r(-.08(0.01)0.08)) ///
				ytitle("EU popularity index", size(med)) xtitle("Days to election") ///
				legend(off) title("Left",box bexpand size(med) ) ///
				saving(left, replace) 


				
reg f1bart $part2 if partisan_kat==2 & gueltig_partisan_kat2==1 , vce (robust)

scalar pval =el(r(table),4,2)
scalar trumpx =el(r(table),1,2)
scalar consx =el(r(table),1,40)
local d  `:di %9.3f _b[1.trump]'
local se `:di %9.2f _se[1.trump]'

graph  twoway 	function y=consx, range(-4 -1) lwidth(thick) lcolor(gs9) ///
				|| function y=(trumpx+consx), range(0 4) lwidth(thick) lcolor(gs0) ///
				,text(.05 -3 "{&delta}{sup:RD} =`d' (`se')", place (e)) ///
				,ylabel(-.08 -.04  0 .04  .08) ///
				ysc(r(-.08(0.01)0.08)) ///
				ytitle("") xtitle("Days to election") ///
				legend(off) title("Center",box bexpand size(med) ) ///
				saving(center, replace) 


				
reg f1bart $part3 if partisan_kat==3 & gueltig_partisan_kat3==1 , vce (robust)

scalar pval =el(r(table),4,2)
scalar trumpx =el(r(table),1,2)
scalar consx =el(r(table),1,40)
local d  `:di %9.3f _b[1.trump]'
local se `:di %9.2f _se[1.trump]'

graph  twoway 	function y=consx, range(-4 -1)  lwidth(thick) lcolor(gs9) ///
				|| function y=(trumpx+consx), range(0 4) lwidth(thick) lcolor(gs0) ///
				,text(.05 -3 "{&delta}{sup:RD} =`d' (`se')**", place (e)) ///
				,ylabel(-.08 -.04  0 .04  .08) ///
				ysc(r(-.08(0.01)0.08)) ///
				ytitle("") xtitle("Days to election") ///
				legend(off) title("Right",box bexpand size(med) ) ///
				saving(right, replace) 


gr combine left.gph center.gph right.gph, xsize(8) ysize(3.5) row(1) ycommon

gr export $graph/Figure5.pdf, as(pdf) replace
foreach u in left.gph center.gph right.gph{
erase `u'
}

**************************by unemployment
reg f1bart $unemp1 if unemp_grob28==1 & gueltig_unemp_grob281==1, vce (robust)

scalar pval =el(r(table),4,2)
scalar trumpx =el(r(table),1,2)
scalar consx =el(r(table),1,21)
local d  `:di %9.3f _b[1.trump]'
local se `:di %9.2f _se[1.trump]'

graph  twoway 	function y=consx, range(-4 -1)  lwidth(thick) lcolor(gs9) ///
				|| function y=(trumpx+consx), range(0 4) lwidth(thick) lcolor(gs0) ///
				,text(.09 -3 "{&delta}{sup:RD} =`d' (`se')", place (e)) ///
				,ylabel(-.3 -.2 -.1 0 .1 .2 .3 ) ///
				ysc(r(-.3(0.1)0.3)) ///
				ytitle("Eu popularity index", size(med)) xtitle("Days to election") ///
				legend(off) title("Low unemployment",box bexpand size(med) ) ///
				saving(unemp_grob1, replace) 

	

reg f1bart $unemp2 if unemp_grob28==2 & gueltig_unemp_grob282==1, vce (robust)

scalar pval =el(r(table),4,2)
scalar trumpx =el(r(table),1,2)
scalar consx =el(r(table),1,21)
local d  `:di %9.3f _b[1.trump]'
local se `:di %9.2f _se[1.trump]'

graph  twoway 	function y=consx, range(-4 -1) lwidth(thick) lcolor(gs9) ///
				|| function y=(trumpx+consx), range(0 4) lwidth(thick) lcolor(gs0)  ///
				,text(.09 -3 "{&delta}{sup:RD} =`d' (`se')", place (e)) ///
				,ylabel(-.3 -.2 -.1 0 .1 .2 .3 ) ///
				ysc(r(-.3(0.1)0.3)) ///
				ytitle("") xtitle("Days to election") ///
				legend(off) title("Medium unemployment",box bexpand size(med) ) ///
				saving(unemp_grob2, replace) 

				

reg f1bart $unemp3 if unemp_grob28==3 & gueltig_unemp_grob283==1, vce (robust)

scalar pval =el(r(table),4,2)
scalar trumpx =el(r(table),1,2)
scalar consx =el(r(table),1,21)
local d  `:di %9.3f _b[1.trump]'
local se `:di %9.2f _se[1.trump]'

graph  twoway 	function y=consx, range(-4 -1)  lwidth(thick) lcolor(gs9) ///
				|| function y=(trumpx+consx), range(0 4) lwidth(thick) lcolor(gs0)  ///
				,text(.09 -3 "{&delta}{sup:RD} =`d' (`se')***", place (e)) ///
				,ylabel(-.3 -.2 -.1 0 .1 .2 .3 ) ///
				ysc(r(-.3(0.1)0.3)) ///
				ytitle("") xtitle("Days to election") ///
				legend(off) title("High unemployment",box bexpand size(med) ) ///
				saving(unemp_grob3, replace) 


				
gr combine unemp_grob1.gph unemp_grob2.gph unemp_grob3.gph , row(1) ysize(3.5) xsize(8) ycommon

gr export $graph/FigureS1.pdf, as(pdf) replace
foreach u in unemp_grob1.gph unemp_grob2.gph unemp_grob3.gph{
erase `u'
}



********************eu or national citizen
reg f1bart $eunat1 if eunationalcit==1 & gueltig_eunationalcit1==1, vce (robust)

scalar pval =el(r(table),4,2)
scalar trumpx =el(r(table),1,2)
scalar consx =el(r(table),1,40)
local d  `:di %9.3f _b[1.trump]'
local se `:di %9.2f _se[1.trump]'

graph  twoway 	function y=consx, range(-4 -1) lwidth(thick) lcolor(gs9) ///
				|| function y=(trumpx+consx), range(0 4) lwidth(thick) lcolor(gs0) ///
				,text(.05 -3 "{&delta}{sup:RD} =`d' (`se')*", place (e)) ///
				,ylabel(-.6 -.4 -.2 0 .2 .4) ///
				ysc(r(-.6(0.1)0.5)) ///
				ytitle("EU popularity Index", size(med)) xtitle("Days to election") ///
				legend(off) title("Only national",box bexpand size(med) ) ///
				saving(eunational1, replace) 
	

reg f1bart $eunat2 if eunationalcit==2 & gueltig_eunationalcit2==1, vce (robust)

scalar pval =el(r(table),4,2)
scalar trumpx =el(r(table),1,2)
scalar consx =el(r(table),1,40)
local d  `:di %9.3f _b[1.trump]'
local se `:di %9.2f _se[1.trump]'

graph  twoway 	function y=consx, range(-4 -1) lwidth(thick) lcolor(gs9) ///
				|| function y=(trumpx+consx), range(0 4) lwidth(thick) lcolor(gs0) ///
				,text(.05 -3 "{&delta}{sup:RD} =`d' (`se')", place (e)) ///
				,ylabel(-.6 -.4 -.2 0 .2 .4) ///
				ysc(r(-.6(0.1)0.5)) ///
				ytitle("", size(med)) xtitle("Days to election") ///
				legend(off) title("National and European",box bexpand size(med) ) ///
				saving(eunational2, replace) 


				
reg f1bart $eunat3 if eunationalcit==3 & gueltig_eunationalcit3==1, vce (robust)

scalar pval =el(r(table),4,2)
scalar trumpx =el(r(table),1,2)
scalar consx =el(r(table),1,40)
local d  `:di %9.3f _b[1.trump]'
local se `:di %9.2f _se[1.trump]'

graph  twoway 	function y=consx, range(-4 -1) lwidth(thick) lcolor(gs9) /// 
				|| function y=(trumpx+consx), range(0 4) lwidth(thick) lcolor(gs0)  ///
				,text(.05 -3 "{&delta}{sup:RD} =`d' (`se')", place (e)) ///
				,ylabel(-.6 -.4 -.2 0 .2 .4) ///
				ysc(r(-.6(0.1)0.5)) ///
				ytitle("", size(med)) xtitle("Days to election") ///
				legend(off) title("European and National",box bexpand size(med) ) ///
				saving(eunational3, replace) 
    

    
reg f1bart $eunat4 if eunationalcit==4 & gueltig_eunationalcit4==1, vce (robust)

scalar pval =el(r(table),4,2)
scalar trumpx =el(r(table),1,2)
scalar consx =el(r(table),1,40)
local d  `:di %9.3f _b[1.trump]'
local se `:di %9.2f _se[1.trump]'

graph  twoway 	function y=consx, range(-4 -1) lwidth(thick) lcolor(gs9) /// 
				|| function y=(trumpx+consx), range(0 4) lwidth(thick) lcolor(gs0) ///
				,text(.05 -3 "{&delta}{sup:RD} =`d' (`se')", place (e)) ///
				,ylabel(-.6 -.4 -.2 0 .2 .4) ///
				ysc(r(-.6(0.1)0.5)) ///
				ytitle("", size(med)) xtitle("Days to election") ///
				legend(off) title("Only European",box bexpand size(med) ) ///
				saving(eunational4, replace) 


				
gr combine eunational1.gph eunational2.gph eunational3.gph eunational4.gph, row(1) ysize(3) xsize(8) ycommon
gr export $graph/FigureS2.pdf, as(pdf) replace

foreach u in eunational1.gph eunational2.gph eunational3.gph eunational4.gph{
erase `u'
}

****************************perceived economic situation of country
reg f1bart $econ1 if count_econ==1 & gueltig_count_econ1==1, vce (robust)

scalar pval =el(r(table),4,2)
scalar trumpx =el(r(table),1,2)
scalar consx =el(r(table),1,40)
local d  `:di %9.3f _b[1.trump]'
local se `:di %9.2f _se[1.trump]'

graph  twoway 	function y=consx, range(-4 -1) lwidth(thick) lcolor(gs9) /// 
				|| function y=(trumpx+consx), range(0 4) lwidth(thick) lcolor(gs0) ///
				,text(.05 -3 "{&delta}{sup:RD} =`d' (`se')*", place (e)) ///
				,ylabel( -.8 -.4 0 .4 .8) ///
				ysc(r(-.8(0.4)0.8)) ///
				ytitle("EU popularity index", size(med)) xtitle("Days to election") ///
				legend(off) title("Very bad",box bexpand size(med) ) ///
				saving(count1, replace) 
	
	

reg f1bart $econ2 if count_econ==2 & gueltig_count_econ2==1, vce (robust)

scalar pval =el(r(table),4,2)
scalar trumpx =el(r(table),1,2)
scalar consx =el(r(table),1,40)
local d  `:di %9.3f _b[1.trump]'
local se `:di %9.2f _se[1.trump]'

graph  twoway 	function y=consx, range(-4 -1) lwidth(thick) lcolor(gs9) /// 
				|| function y=(trumpx+consx), range(0 4) lwidth(thick) lcolor(gs0) ///
				,text(.05 -3 "{&delta}{sup:RD} =`d' (`se')", place (e)) ///
				,ylabel( -.8 -.4 0 .4 .8) ///
				ysc(r(-.8(0.4)0.8)) ///
				ytitle("", size(med)) xtitle("Days to election") ///
				legend(off) title("Rather bad",box bexpand size(med) ) ///
				saving(count2, replace) 
	

	
reg f1bart $econ3 if count_econ==3 & gueltig_count_econ3==1, vce (robust)

scalar pval =el(r(table),4,2)
scalar trumpx =el(r(table),1,2)
scalar consx =el(r(table),1,40)
local d  `:di %9.3f _b[1.trump]'
local se `:di %9.2f _se[1.trump]'

graph  twoway 	function y=consx, range(-4 -1) lwidth(thick) lcolor(gs9) /// 
				|| function y=(trumpx+consx), range(0 4) lwidth(thick) lcolor(gs0) ///
				,text(.05 -3 "{&delta}{sup:RD} =`d' (`se')", place (e)) ///
				,ylabel( -.8 -.4 0 .4 .8) ///
				ysc(r(-.8(0.4)0.8)) ///
				ytitle("", size(med)) xtitle("Days to election") ///
				legend(off) title("Rather good",box bexpand size(med) ) ///
				saving(count3, replace) 
	

    
reg f1bart $econ4 if count_econ==4 & gueltig_count_econ4==1, vce (robust)

scalar pval =el(r(table),4,2)
scalar trumpx =el(r(table),1,2)
scalar consx =el(r(table),1,40)
local d  `:di %9.3f _b[1.trump]'
local se `:di %9.2f _se[1.trump]'

graph  twoway 	function y=consx, range(-4 -1) lwidth(thick) lcolor(gs9) /// 
				|| function y=(trumpx+consx), range(0 4) lwidth(thick) lcolor(gs0) ///
				,text(.05 -3 "{&delta}{sup:RD} =`d' (`se')", place (e)) ///
				,ylabel( -.8 -.4 0 .4 .8) ///
				ysc(r(-.8(0.4)0.8)) ///
				ytitle("", size(med)) xtitle("Days to election") ///
				legend(off) title("Very good",box bexpand size(med) ) ///
				saving(count4, replace) 
    

	
gr combine count1.gph count2.gph count3.gph count4.gph, row(1) ysize(3) xsize(8) ycommon
gr export $graph/Figure4.pdf, as(pdf) replace

foreach u in count1.gph count2.gph count3.gph count4.gph{
erase `u'
}

**************************************************************************************************
***********************Exclude countries with significant holidays********************************
**************************************************************************************************
reg f1bart trump frau age  occ_kat1 occ_kat3 occ_kat4 occ_kat5 occ_kat6 occ_kat7  ///
town bilzeit b27.country if (country !=1 & country!=2 & country!=9 & country !=4 ///
& country !=23 & country !=17 & country !=19 & country !=26 & country !=5 & country !=7) , vce (robust)
eststo

#delimit ;
esttab	using $tab/TableS14.rtf, replace 
	nonumbers
	b(%9.3f) se(2) wide
	r2(2) 
	label
	compress
	nogaps
	drop(*country)
	title ("Table S14. Excluding countries with commemoration holidays. DV: EU popularity index.")
	star
	addnotes ("Treatment group: Interviewed after the presidential election. Robust standard errors in parentheses. Own calculations, based on Eurobarometer 86.2, not weighted. ")
;
#delimit cr

eststo clear



**************************************************************************************************
********************Items after Teney et al. (2014) and Teney (2016)******************************
**************************************************************************************************
reg f1bart trump frau age occ_kat1 occ_kat3 occ_kat4 occ_kat5 occ_kat6 occ_kat7 town bilzeit b27.country if gueltig==1 & ratcosmopolitan>.6, vce (robust)
eststo
reg f1bart trump frau age occ_kat1 occ_kat3 occ_kat4 occ_kat5 occ_kat6 occ_kat7 town bilzeit b27.country if gueltig==1 & ratutilitarian>.6 , vce (robust)
eststo
reg f1bart trump frau age occ_kat1 occ_kat3 occ_kat4 occ_kat5 occ_kat6 occ_kat7 town bilzeit b27.country if gueltig==1 & ratcommunitarian>.6, vce (robust)
eststo
reg f1bart trump frau age occ_kat1 occ_kat3 occ_kat4 occ_kat5 occ_kat6 occ_kat7 town bilzeit b27.country if gueltig==1 & ratliberitarian>.6, vce (robust)
eststo


#delimit ;
esttab	using $tab/TableS8.rtf, replace 
	nonumbers
	b(%9.3f) se(2) wide
	r2(2) 
	label
	compress
	mlabels ("Cosmopolitan (>.6)" "Utilitarian (>.6)" "Communitarian (>.6)" "Liberitarian (>.6)")
	nogaps
	drop(*country)
	title ("Table S8. Subgroup analysis by ideology following Teney et al. 2014. DV: EU popularity index.")
	star
	addnotes ("Treatment group: Interviewed after November 9. Robust standard errors in parentheses. Own calculations, based on Eurobarometer 86.2, not weighted.")
;
#delimit cr

eststo clear


**************************************************************************************************
***********************Different DVs (partisanship, feelings toward EU****************************
**************************************************************************************************
reg partisan trump frau age occ_kat1 occ_kat3 occ_kat4 occ_kat5 occ_kat6 occ_kat7 town bilzeit b27.country if gueltig==1  , vce (robust)
est sto DVpart

reg immiEU trump frau age occ_kat1 occ_kat3 occ_kat4 occ_kat5 occ_kat6 occ_kat7 town bilzeit b27.country if gueltig==1  , vce (robust)
est sto DVimmiEU


#delimit ;
esttab DVpart DVimmiEU using $tab/TableS18.rtf, replace 
	nonumbers
	b(%9.3f) se(2) wide
	r2(2) 
	label
	compress
	mlabels ("DV: Political ideology" "DV: Positive feelings toward immigrants from EU")
	nogaps
	drop(*country)
	title ("Table S18. Model with different DV's representing chauvinism vs. cosmopolitanism. ")
	star
	addnotes ("Treatment group: Interviewed after the presidential election. Days: Number of days since the election. Robust standard errors in parentheses. EB 2016, own calculations, not weighted.")
;
#delimit cr

eststo clear


**************************************************************************************************
***********************Matching*******************************************************************
**************************************************************************************************

************psmatch
teffects psmatch (f1bart) (trump frau i.agekat occ_kat1 occ_kat3 occ_kat4 occ_kat5 occ_kat6 occ_kat7  ///
town bilzeit)


***********nearest neighbor matching
teffects nnmatch (f1bart frau i.agekat occ_kat1 occ_kat3 occ_kat4 occ_kat5 occ_kat6 occ_kat7  ///
town bilzeit) (trump), biasadj(bilzeit)  
 

*************************************************************************************************************
**************************Regressions using trust in EU as robustness check**********************************
*************************************************************************************************************
logit trust trump i.frau age i.town bilzeit occ_kat1 occ_kat3 occ_kat4 occ_kat5 occ_kat6 occ_kat7 ///
if gueltig==1, vce (robust) 
est sto trust

#delimit ;
esttab trust using $tab\TableS12.rtf, replace 
	nonumbers
	b(%-9.0g 3) se(3)  wide
	star(* 0.05 ** 0.01 *** 0.001)
	label
	compress
	nogaps
	aic bic
	scalars(ll chi2 chi2_c)
	title ("Table S12. Logit regression. DV: Trust in the EU.")
	addnotes ("Treatment group: Interviewed after November 9. Robust standard errors in parentheses. Own calculations, based on Eurobarometer 86.2, not weighted. * p < 0.05, ** p < 0.01, *** p < 0.001.")
;
#delimit cr


*************************************************************************************************************
**************************Regressions by pol. sophistication and region**************************************
*************************************************************************************************************

************political sophistication
reg f1bart i.trump##c.correct frau age  town ib2.occ_kat bilzeit i.country, vce (robust) level(90)
est sto knowledge

************region east/west
reg f1bart i.trump##i.east frau age  town ib2.occ_kat bilzeit i.country, vce (robust) level(90)
est sto east

************south/north
reg f1bart i.trump##i.south frau age  town ib2.occ_kat bilzeit i.country, vce (robust) level(90)
est sto south


#delimit ;
esttab knowledge east south using $tab/TableS11.rtf, replace 
	nonumbers
	mlabels ("Political sophistication" "East/West" "South/North")
	b(%9.3f) se(3) wide
	r2(2) 
	label
	compress
	nogaps
	drop(*country)
	title ("S11. Robustness check including political sophistication, East/West split, South/North split. DV: EU popularity Index")
	star
	addnotes ("Treatment group: Interviewed after November 9. Robust standard errors in parentheses. Own calculations, based on Eurobarometer 86.2, not weighted. ")
;
#delimit cr

**************************************************************************************************
*********************************Sample restriction by age****************************************
**************************************************************************************************
bys trump: su age


**************neue gueltig variable
reg f1bart trump frau age  i.occ_kat town bilzeit b27.country if gueltig==1 & age<64, vce (robust)
gen gueltigalt=e(sample)


***********descriptives
eststo: estpost summarize f1bart bilzeit frau occ_kat1 occ_kat2 occ_kat3 occ_kat4 occ_kat5 occ_kat6 occ_kat7 age ///
town if trump==0 & gueltigalt==1

eststo: estpost summarize f1bart bilzeit frau occ_kat1 occ_kat2 occ_kat3 occ_kat4 occ_kat5 occ_kat6 occ_kat7 age ///
town if trump==1 & gueltigalt==1


esttab using $tab/TableS2.rtf, replace ///
			 cell("count mean(fmt(a2)) sd(fmt(a2)) min(fmt(a2)) max(fmt(a2))") ///
			 mti collabels(none) nonum noobs label nodepvar ///
			 mlabels(,none) title ("Table S2. Descriptive statistics excluding respondents age > 63.") addnotes  ///
			("Note: Based on Eurobarometer 86.2, own calculations, not weighted; SD=Standard deviation, education was top-coded at 26 years to reduce the influence of outliers. ")

eststo clear


***********check if sample is balanced
foreach u in town age occ_kat1 occ_kat2 occ_kat3 occ_kat4 occ_kat5 occ_kat6 occ_kat7 ///
f1bart bilzeit frau{
di "`u'"
ttest `u' if gueltigalt==1, by(trump) level(99.9) unequal
}


*******************regression
reg f1bart trump if gueltigalt==1, vce (robust)
est sto small
reg f1bart trump frau age occ_kat1 occ_kat3 occ_kat4 occ_kat5 occ_kat6 occ_kat7 ///
town bilzeit b27.country if gueltigalt==1, vce (robust) 
est sto norm 
reg f1bart i.trump##c.trump_c frau age  occ_kat1 occ_kat3 occ_kat4 occ_kat5 occ_kat6 occ_kat7 /// 
town bilzeit b27.country if gueltigalt==1, vce (robust) 
est sto interact


#delimit ;
esttab small norm interact using $tab/TableS3.rtf, replace 
	nonumbers
	b(%9.3f) se(3) wide
	mlabels ("(1)" "(2)" "(3)")
	r2(2) 
	label
	compress
	nogaps
	drop(*country)
	title ("Table S3. Robustness check: Excluding respondents older than 63 years. DV: EU popularity index.")
	star
	addnotes ("Treatment group: Interviewed after November 9. Robust standard errors in parentheses. Own calculations, based on Eurobarometer 86.2, not weighted. Excluding respondents older than 63 years. ")
;
#delimit cr

eststo clear


**************************************************************************************************
***************************Robustness check to Tbale S9*******************************************
*****************************adjusted pupularity index********************************************
**************************************************************************************************

*********construct new factor excluding 'felling attached to EU'
*********and ' feeling like being a EU citizen'

global fact2 mod demos protec effic forw  ///
optifut jobs busni demo respect 

factor $fact2

screeplot, yline(1)
predict f1bart2, bartlett
label var f1bart2 "adjusted EU popularity index"

*****by national pride
reg f1bart2 trump frau age occ_kat1 occ_kat3 occ_kat4 occ_kat5 occ_kat6 occ_kat7 town bilzeit b27.country if gueltig==1 & eunationalcit==1, vce (robust)
eststo
reg f1bart2 trump frau age occ_kat1 occ_kat3 occ_kat4 occ_kat5 occ_kat6 occ_kat7 town bilzeit b27.country if gueltig==1 & eunationalcit==2, vce (robust)
eststo
reg f1bart2 trump frau age occ_kat1 occ_kat3 occ_kat4 occ_kat5 occ_kat6 occ_kat7 town bilzeit b27.country if gueltig==1 & eunationalcit==3, vce (robust)
eststo
reg f1bart2 trump frau age  occ_kat1 occ_kat3 occ_kat4 occ_kat5 occ_kat6 occ_kat7 town bilzeit b27.country if gueltig==1 & eunationalcit==4, vce (robust)
eststo



#delimit ;
esttab	using $tab/eunationalnewfactor.rtf, replace 
	nonumbers
	b(%9.2f) se(2) wide
	r2(2) 
	label
	compress
	mlabels ("national" "national and european" "european and national" "european only")
	nogaps
	drop(*country)
	title ("Robustness check to Table S9. DV: adjusted EU popularity index")
	star
	addnotes ("Treatment group: Interviewed after November 9. Robust standard errors in parentheses. Own calculations, based on Eurobarometer 86.2, not weighted.")
;
#delimit cr

eststo clear

