set more off

use $data/eurobarometer2016, clear

******************generate treatment variable
gen trump=.
replace trump=1 if p1>6
replace trump=0 if p1<7
numlabel, add
ta p1 trump



lab variable trump "Treatment group"


**************clean countries
numlabel, add
ta country

gen count=.

replace count=1  if country==1
replace count=2  if country==2
replace count=3  if country==3
replace count=4  if country==4 | country==14
replace count=5  if country==5
replace count=6  if country==6
replace count=7  if country==7
replace count=8  if country==8
replace count=9  if country==9 | country==10
replace count=10 if country==11
replace count=11 if country==12
replace count=12 if country==13
replace count=13 if country==16
replace count=14 if country==17
replace count=15 if country==18
replace count=16 if country==19 | country==33
replace count=17 if country==20
replace count=18 if country==21
replace count=19 if country==22
replace count=20 if country==23
replace count=21 if country==24
replace count=22 if country==25
replace count=23 if country==26
replace count=24 if country==27
replace count=25 if country==28
replace count=26 if country==30
replace count=27 if country==31
replace count=28 if country==32
replace count=29 if country==34
replace count=30 if country==35
replace count=31 if country==36
replace count=32 if country==37


 #delimit ;

lab def labcountry  1 "France" 
					2 "Belgium"
					3 "Netherlands" 	
					4 "Germany"
					5 "Italy"
					6 "Luxembourg"
					7 "Denmark"
					8 "Ireland"
					9 "UK"
					10 "Greece"
					11 "Spain"
					12 "Portugal"
					13 "Finland"
					14 "Sweden"
					15 "Austria"
					16 "Cyprus"
					17 "Czech Republic"
					18 "Estonia"
					19 "Hungary"
					20 "Latvia"
					21 "Lithuania"
					22 "Malta"
					23 "Poland"
					24 "Slovakia"
					25 "Slovenia"
					26 "Romania"
					27 "Turkey"
					28 "Croatia"
					29 "Macedonia/FYROM"
					30 "Montenegro"
					31 "Serbia"
					32 "Albania";
					
  #delimit cr


lab val count labcountry

drop if country==29
drop country 
rename count country

********************************************************************************
***********clean and recode variables*******************************************
********************************************************************************

****************gender 
ta d10, m
recode d10 (1=0) (2=1)
rename d10 frau

lab var frau "Female"


*******************eduaction in years
gen bilzeit=d8 
replace bilzeit=26 if bilzeit>26 & bilzeit<96
ta bilzeit

recode bilzeit(99  0=.)

***no full-time education and students coded zero
replace bilzeit=0 if d8==97 | d8==98

lab var bilzeit "Education (in years)"


*********************Partisanship
recode d1 (97 98 =.)
rename d1 partisan

recode d1r1 (9=.)
rename d1r1 partisan_kat
ta partisan_kat, gen(partisan_kat)

lab var partisan_kat1 "Left"
lab var partisan_kat2 "Center"
lab var partisan_kat3 "Right"

**********************occupation
ta d15a_r2, m

gen occ_kat=d15a_r2
recode occ_kat (1=1) (2 3=2) (4=3) (5=4) (6=5) (7=6) (8=7)

ta occ_kat d15a_r2


ta occ_kat, gen(occ)
lab var occ1 "Self-employed" 
lab var occ2 "White collar"  
lab var occ3 "Manual" 
lab var occ4 "Homemaker" 
lab var occ5 "Unemployed"
lab var occ6 "Retired" 
lab var occ7 "Student"


*****************age
ta d11
recode d11 (99=.)
rename d11 age

lab var age "Age"


*****************age-categories for matching
su age, det

egen agekat=xtile(age), p(10 30 50 70 90)

ta agekat, gen(agekat)


*****************rural vs. urban
gen town=d25
recode town (1=0) (2 3=1)

lab var town "small/middle/large Town"


*******************perceived economic situation of the country
ta qa1a_1 
gen count_econ=.
replace count_econ=4 if qa1a_1==1
replace count_econ=3 if qa1a_1==2
replace count_econ=2 if qa1a_1==3
replace count_econ=1 if qa1a_1==4

lab var count_econ    "Situation: national economy"
lab def econ2 		4 "very good" ///
					3 "rather good"   ///
					2 "rather bad" ///
					1 "very bad"
			 
			 
label values count_econ econ2


********************************************************************************
***********recode and clean variables for DV Factor*****************************
********************************************************************************

***************EU concept modern
ta qa12_1, m

recode qa12_1 (1=4 "describes very well")(2=3 "describes fairly well")(4=1 "describes very badly") ///
(3=2 "describes fairly badly")(5=.), into(mod)

lab variable mod "EU concept modern"


***************EU concept democtratic
ta qa12_2, m 

recode qa12_2 (1=4 "describes very well")(2=3 "describes fairly well")(4=1 "describes very badly") ///
(3=2 "describes fairly badly")(5=.), into(demos)

lab variable demos "EU concept democtratic"


***************EU concept protective
ta qa12_3, m

recode qa12_3 (1=4 "describes very well")(2=3 "describes fairly well")(4=1 "describes very badly") ///
(3=2 "describes fairly badly")(5=.), into(protec)

lab variable protec "EU concept protective"


***************EU concept efficient
ta qa12_4, m

recode qa12_4 (1=4 "describes very well")(2=3 "describes fairly well")(4=1 "describes very badly") ///
(3=2 "describes fairly badly")(5=.), into(effic)

lab variable effic "EU concept efficient"


***************EU concept forward-looking
ta qa12_6, m

recode qa12_6 (1=4 "describes very well")(2=3 "describes fairly well")(4=1 "describes very badly") ///
(3=2 "describes fairly badly")(5=.), into(forw)

lab variable forw "EU concept forward looking"


**********************trust in EU
ta qa8a_14, m
ta qa8b_2, m

gen trust=.
replace trust=1 if  qa8a_14==1 |  qa8b_2==1
replace trust=0 if  qa8a_14==2 |  qa8b_2==2

lab def trustlab 1 "Tend to trust" ///
				 0 "Tend not to trust"

label values trust trustlab				 
lab variable trust "Trust in EU"


*******************optimistic/pesimistic in Eu's future 
ta qa20, m

recode qa20 (1=4 "very optimistic") (2=3 "fairly optimistic") ///
(4=1 "very pessimistic") (3=2 "fairly pessimistic")(5=.), into(optifut)

lab variable optifut "optimistic/pessimistic EU future"


************************EU creates more jobs
ta qa13_1, m

recode qa13_1 (4=1 "totally disagree") (3=2 "tend to  disagree") ///
(1=4 "totally agree") (2=3 "tend to agree")(5=.), into(jobs)

lab variable jobs "EU creates jobs"


***********************Eu makes doing business easier
ta qa13_2, m

recode qa13_2 (4=1 "totally disagree") (3=2 "tend to  disagree") ///
(1=4 "totally agree") (2=3 "tend to agree")(5=.), into(busni)

lab variable busni "EU makes business easier"


*************************satisfaction with EU democracy 
ta qa18b, m

recode qa18b  (4=1 "not at all satsified") (3=2 "not very staisfied") ///
			  (2=3 "fairly satsified") (1=4 "very satisfied")(5=.), into(demo)

lab variable demo "Satisfaction w/ EU democracy"


************************Attachement to EU
gen attacheu=.
replace attacheu=4 if qd1a_3==1 |  qd1b_3==1
replace attacheu=3 if qd1a_3==2 |  qd1b_3==2
replace attacheu=2 if qd1a_3==3 |  qd1b_3==3
replace attacheu=1 if qd1a_3==4 |  qd1b_3==4 

lab def attachlab2	 	4 "Very attached" 	///
						3 "Fairly attached"	///
						2 "Not very attached" ///
						1 "Not at all attached"
				 
label values attacheu attachlab2
lab variable attacheu "Attachement to: EU"


***************feel like EU citizen
gen eucitizen=.
replace eucitizen=4 if qd2_1==1
replace eucitizen=3 if qd2_1==2
replace eucitizen=2 if qd2_1==3
replace eucitizen=1 if qd2_1==4

lab def eucit2		 	4 "Yes" 	///
						3 "To some extent"	///
						2 "Not really" ///
						1 "No"
				 
label values eucitizen eu
lab variable eucitizen "Fell to be EU citizen"


***************national or EU citizen
ta qd3, m

recode qd3 (1=1 "national") (2=2 "national and european") ///
(3=3 "european and national") ///
(4=4 "european only")(5 6 7 .i =.), into(eunationalcit)

lab variable eunationalcit "More EU than national citizen"

*************************interst of own country taking into accoutn
ta qa19a_2, m

recode qa19a_2 (1=4 "totally agree") (2=3 "tend to agree") ///
		       (4=1 "totally disagree") (3=2 "tend to disagree") ///
			   (5=.), into(respect)
			   
lab variable respect "EU respects country interest"


*************************felling to immigration from EU members
ta qb4_1, m
recode qb4_1   (1=4 "very positive") (2=3 "fairly positive") ///
		       (4=1 "very negative") (3=2 "fairly negative") ///
			   (5=.), into(immiEU)

lab variable immiEU "Feelings toward immigrants from EU"


**********************Measure for EU knowledge
gen correct=.
replace correct=1 if qa16t2==1
replace correct=2 if qa16t3==1
replace correct=3 if qa16t4==1
replace correct=4 if qa16t5==1

lab def correctlab 1 "Zero" ///
				   2 "one" ///
				   3 "two" ///
				   4 "three"
				   
label values correct correctlab				   
lab var correct "Knowledge: Correct anserws EU questions"

**************************************************************************************************
****************Items following Teney et al. (2014) and Teney (2016)******************************
**************************************************************************************************

bys caseid: gen sum= (qa11_1+ qa11_3+qa11_5+qa11_6 +qa11_7+qa11_4 + qa11_2+ qa11_13 +qa11_14 + qa11_12 +qa11_9+ qa11_11+qa11_10) 

*1. positive non-materialistic framing of Eu
ta qa11_1 		//Peace
ta qa11_3 		//democracy
ta qa11_5		//freedom to travel/study/work
ta qa11_6 		//cultural diversity
ta qa11_7 		//stronger say in the world

bys caseid: gen sumcosmopolitan= (qa11_1+ qa11_3+qa11_5+qa11_6 +qa11_7) 
bys caseid: gen ratcosmopolitan=sumcosmopolitan/sum
gen ratcosmopolitan2=ratcosmopolitan
recode ratcosmopolitan2 (0=.)

lab variable ratcosmopolitan "Positive non-materialistic framing EU (cosmopolitan)"



*2. positive materialistic framing of Eu
ta qa11_4 		//Social protection
ta qa11_2 		//economic prosperity

bys caseid: gen sumutilitarian= (qa11_4 +qa11_2) 
bys caseid: gen ratutilitarian=sumutilitarian/sum

lab variable ratutilitarian "Positive materialistic framing EU (utilitarian)"


*3. negative non-materialistic framing of Eu
ta qa11_13 		// more crime
ta qa11_14 		//not enough frontier control
ta qa11_12 		//loss of cultural identity
ta qa11_9 		//unemployment

bys caseid: gen sumcommunitarian= (qa11_13+qa11_14+qa11_12+qa11_9) 	
bys caseid: gen ratcommunitarian=sumcommunitarian/sum

lab variable ratcommunitarian "negative non-materialistic framing of Eu (communitarian)"

*4. negative materialistic framing of Eu
ta qa11_11 		// waste of money
ta qa11_10 		//bureaucracy

bys caseid: gen sumliberitarian= (qa11_11+qa11_10) 	
bys caseid: gen ratliberitarian=sumliberitarian/sum

lab variable ratliberitarian "negative materialistic framing of Eu (liberitarian)"


********************************************************************************				   
*************generate regional dummies***************************************
********************************************************************************
***http://www.staatenkunde.de/dgfs/datenbank/db-sb.php?sb=16&k=4

****east/west
gen east=0
replace east=1 if country==23 | country==24 | country==17 | country==19

*****north/south
gen south=0
replace south=1 if country==25 | country==11 | country==12 | country==22 | country==5 	

********************************************************************************				   
*************generate categorical dummies***************************************
********************************************************************************
ta occ_kat, gen(occ_kat)
ta eunationalcit, gen(eunationalcit)
ta count_econ, gen(count_econ)


********************************************************************************				   
*************clean data set*****************************************************
********************************************************************************
keep country trump p1 frau bilzeit partisan partisan_kat* occ* ///
age* town* count_econ* mod demos protec effic forw east south ///
trust optifut jobs busni demo attach* eucitizen respect ///
eunationalcit* immiEU correct eu28 eu27b eurnz* d11r* rat*


********************************************************************************				   
*************merge EB with unemployment data************************************
********************************************************************************
merge m:m country using $data\unemployment
drop _merge


********generate unemployment subgroups
egen unemp_grob28=xtile(unemp) if eu28==1, percentiles (33.33333333333 66.666666666) 
ta unemp_grob28, gen(unemp_grob28)


********************************************************************************				   
*************merge EB with unemployment change rate data************************
********************************************************************************

merge m:m country using $data\uemp2
drop _merge


********generate unemployment change rate subgroups
egen unempchange_kat=xtile(unemp_change) if eu28==1, percentiles (33.33333333333 66.666666666) 
ta unempchange_kat, gen(unempchange_kat)

********************************************************************************				   
*************save final dataset*************************************************
********************************************************************************

save $data\eurobarometer2016Trump2, replace
